######################################################################################
# Important:
# The scope of this script is tied directly to WAS PMR 21066,999,000, which is not
# providing in a refresh WAS fixpack yet. If this iFIX is not already applied on
# the system before running this script, a failure will most likely to happen.
# You've been warned!
#
# More information about deploying a console module, see the following link
# http://publib.boulder.ibm.com/infocenter/wasinfo/v6r1/index.jsp?topic=/com.ibm.websphere.nd.multiplatform.doc/info/ae/isc/deploy_comp.html
#
# Detail:
# With this fix, -skipPreparation, an isclite update would now need to be a 2-step process
#    1. Deploy the WAR file to isclite with only the required options (add, contents, contenturi, usedefaultbindings)
#    2. Perform the WAR file edit operation with any additional options (context root, roles,etc..)
#
# The 1st step would not normally change but the 2nd step should be taken into
# consideration per application owner need
######################################################################################


import sys


###############################################################################
# Usage
###############################################################################
def printUsage():
    print "Usage:  <was_profile_dir>/bin/wsadmin -lang jython -f installISCWar.py <serverName> <warFile> <contentURI> <contextRoot>  <moduleName>"
    print "   where <was_profile_dir>   is your was profile directory"
    print "         <serverName>        is the server name of the server"
    print "         <warFile>           is the fully qualified path WAR file"
    print "         <contentURI>        is the content URI, normally same as the WAR file name"
    print "         <contextRoot>       is the context root to map to"
    print "         <moduleName>        is the <display-name> from web.xml"

###############################################################################
# Deploy an ISC War file to isclite application already existed by ISC
#
# parameters:
#
# serverName   - the name of the WAS server
# warFile      - the fully qualified path WAR file"
# contentURI   - the content URI
#
# return:
#    0 - if successful
#    1 - if failed
#
###############################################################################
def doDeploy(serverName, warFile, contentURI) :
    methodName ="doDeploy("+ serverName +","+warFile+","+contentURI+")"
    print "ENTER:"+methodName
    rc=1

    #moduleURI = moduleName +" "+contentURI+",WEB-INF/web.xml"
    options = ["-operation add -skipPreparation -contents "+warFile+" -server "+serverName+" -contenturi "+ contentURI +" -usedefaultbindings" ]

    try:
        print "Ready to deploy "+warFile
        AdminApp.update('isclite', 'modulefile', options)
        rc=0
    except:
        error = str(sys.exc_info()[1])
        print "Exception occurred during doDeploy(" + server + "):", error
        # Cannot catch this yet
        # if error.count("0166E") > 0: # catch  ADMA0166E (app with given name already exists)
        #     print "Application module is already installed."
        #    rc=0
        #else:
        #    print "Exception occurred during deployISCWar(" + server + "):", error

    print "EXIT:"+methodName+":",rc
    return rc

###############################################################################
# Edit an existing ISC WAR file with additional attributes
# such as map to virtual host, role, etc..
#
# parameters:
#
# contentURI   - the content URI
# moduleName   - the application module name
# editOpts     - the options to add to the WAR file
#
# return:
#    0 - if successful
#    1 - if failed
#
###############################################################################
def doEdit(contentURI, moduleName, editOpts) :
    methodName ="doEdit("+ contentURI+","+moduleName+","+"editOpts[])"
    print "ENTER:",methodName
    #Build up the arguments for edit operation
    #appModuleOpt: the application module name which looks like: isclite#<ABC>.war+WEB-INF/web.xml
    # For example, for cgiservlet.war the application module should look like
    # isclite#cgiservlet.war+WEB-INF/web.xml
    appModuleOpt = "isclite#"+contentURI+"+WEB-INF/web.xml"
    rc=1

    try:
        print "Ready to edit "+warFile
        AdminApp.edit(appModuleOpt,editOpts)
        rc=0
    except:
        error = str(sys.exc_info()[1])
        print "Exception occurred during deployISCWar(" + server + "):", error

    print "EXIT:"+methodName+":",rc
    return rc


###############################################################################
# Main block -- script execution starts here.
# TIPProfile_bin/wsadmin.bat -conntype none -lang jython
#                                           -f C:/projects/working/TIPInstall/scripts/tipDeployISCWar.py
#                                           server1
#                                           ../../../systemApps/isclite.ear/cgiservlet.war
#                                           cgiservlet.war
#                                           /cgiservlet
#                                           cgiservletWAR
###############################################################################

# Verify the correct number or parameters was passed in
if not (len(sys.argv) == 5):
   sys.stderr.write("Invalid number of arguments\n")
   printUsage()
   sys.exit(101)

# retrieve the cell name
serverName = sys.argv[0]

#War file name with full path
warFile = sys.argv[1]

#Content URI
contentURI = sys.argv[2]

#Context root
contextRoot = sys.argv[3]

#Module name (this is the <display-name> from your web.xml)
moduleName = sys.argv[4]


successString = "SUCCESSFUL"

#Always build this first
moduleURI = moduleName +" "+contentURI+",WEB-INF/web.xml"

#Options for edit operation and must be done after the WAR file has been deployed
mapToVhOpt = "-MapWebModToVH [["+moduleURI+" admin_host]]"
mapToContextRootOpt = "-CtxRootForWebMod [["+moduleURI+" "+contextRoot+"]]"
editOpts = []
editOpts.append(mapToVhOpt)
editOpts.append(mapToContextRootOpt)

#Start the operation here
returnCode = doDeploy(serverName,warFile,contentURI)

if returnCode == 0:
    returnCode = doEdit(contentURI,moduleName,editOpts)
    if returnCode == 0:
        print successString
        AdminConfig.save()

sys.exit(returnCode)
