############################################################ {COPYRIGHT-TOP} ###
# IBM Confidential
# OCO Source Materials
# Tivoli Common Reporting Infrastructure
# 5724-Q87
#
# (c) Copyright IBM Corp. 2007
#
# The source code for this program is not published or otherwise
# divested of its trade secrets, irrespective of what has been
# deposited with the U.S. Copyright Office.
############################################################ {COPYRIGHT-END} ##
# wsadmin jython script for creating a shared library.
# The shared library is associated with the classloader of the
# application server, so all applications running in the application
# server will use the same classes in the shared library.

import sys

# Note:  script execution starts below at the main block

#-----------------------------------------
# Usage
#-----------------------------------------
def printUsage():
    print "Usage:  <was_profile_dir>/bin/wsadmin -lang jython -f addSharedLib.py <cellName> <nodeName> <serverName> <installDir>"
    print "   where <was_profile_dir>   is your was profile directory"
    print "         <cellName>          is the cell name of the server"
    print "         <nodeName>          is the node name of the server"
    print "         <serverName>        is the server name of the server"
    print "         <installDir>        is the path of the TCR installation"

###############################################################################
# definition of the add routine
#
# parameters:
#
# nodeName   - the name of the node containing the server
# serverName - the name of the server to configure with the shared library
# shLibName  - the name of the shared library
# shLibDesc  - the description of the shared library name
# shLibValue - the value of the shared library including the fully qualified path to the jars
#              if there are more than one jars, the user of this script is responsible for constructing
#              this value (ie, E:/ibm/tivoli/tip/coreapi.jar;E:/ibm/tivoli/tip/engineapi.jar; )
#
###############################################################################
def add( nodeName, serverName, shLibName, shLibDesc, shLibValue, app ):

   # variables used below
   global AdminConfig
   global AdminControl

   # make sure the node exists
   fullNodeName = "/Node:" + nodeName + "/"
   print "Looking for Node: " + fullNodeName
   nodeId = AdminConfig.getid(fullNodeName)
   if len(nodeId) == 0:
      print "   Exiting because the Node was not found"
      return
   else:
      print "   Found Node: "  + nodeId

   # make sure the server exists in the node
   fullServerName = "/Node:" + nodeName + "/Server:" + serverName + "/"
   print "Looking for Server: " + fullServerName
   serverId = AdminConfig.getid(fullServerName)
   if len(serverId) == 0:
      print "   Exiting because the Server was not found"
      return
   else:
      print "   Found Server: "  + serverId

   # make sure an application server exists for the server
   print "Looking for ApplicationServer for the Server"
   appServerId = AdminConfig.list('ApplicationServer',serverId)
   if len(appServerId) == 0:
      print "   Exiting because the ApplicationServer was not found"
      return
   else:
      print "   Found AplicationServer: " + appServerId

   #Remove now
   remove(shLibName)

   # create shared library
   #classpath = directory + LIBRARY_JAR_1 + directory + LIBRARY_JAR_2 + directory + LIBRARY_JAR_3 + directory + LIBRARY_JAR_4 + directory + LIBRARY_JAR_5 + directory + LIBRARY_JAR_6 + directory + LIBRARY_JAR_7
   print "Creating Library"
   libraryId = AdminConfig.create('Library', nodeId, [['name', shLibName], ['description',shLibDesc], ['classPath', shLibValue]])
   print "   Created Library: " + libraryId

   # look for the classloader for the application
   print "Looking for Classloader for the Application " + app
   appId = AdminConfig.getid('/Deployment:' + app + '/');
   classLoaderIds = AdminConfig.list('Classloader',appId).split(lineSeparator)
   classLoaderId = ""

   # create the classloader if it does not exist
   if len(classLoaderIds) == 0:
      print "   Did not find Classloader, creating a new Classloader"
      classLoaderId = AdminConfig.create('Classloader', appId, [['libraries', []], ['mode', 'PARENT_LAST']])
      print "      Created Classloader: " + classLoaderId
   else:
      classLoaderId = classLoaderIds[0]
      print "   Found Classloader: " + classLoaderId

   # remove any existing references to the shared library
   existingLibraryRefIds = AdminConfig.list('LibraryRef',classLoaderId).split(lineSeparator)
   print "Found number of existing LibraryRefs: %s" % (len(existingLibraryRefIds))
   for existingLibraryRefId in existingLibraryRefIds:
      if len(existingLibraryRefId) > 0:
         existingLibraryRefLibraryName = AdminConfig.showAttribute(existingLibraryRefId, 'libraryName')
         print "      LibraryRef libraryName: " + existingLibraryRefLibraryName
         if existingLibraryRefLibraryName == shLibName:
            print "      Removing LibraryRef"
            AdminConfig.remove(existingLibraryRefId)
            print "      Removed LibraryRef"

   # create library ref associating appserver class to shared library
   print "Creating LibraryRef"
   libraryRefId = AdminConfig.create('LibraryRef', classLoaderId, [['libraryName', shLibName],  ['sharedClassloader', 'true']])
   print "   Created LibraryRef: " + libraryRefId

   # Save all the changes made by this routine
   print "Saving all configuration changes made by addSharedLib"
   AdminConfig.save()
   print "   Saved all configuration changes"


###############################################################################
# definition of the remove routine
#
# parameters:
#
# shLibName   - the name of the node shared library
#
###############################################################################
def remove(shLibName):
   # remove any existing instances of the shared library
   existingLibraryIds = AdminConfig.list('Library').split(lineSeparator)
   print "Found number of existing Libraries: %s" % (len(existingLibraryIds))
   for existingLibraryId in existingLibraryIds:
      print "   Next Library: " + existingLibraryId
      if len(existingLibraryId) > 0:
         existingLibraryName = AdminConfig.showAttribute(existingLibraryId, 'name')
         print "      Library name: " + existingLibraryName
         if existingLibraryName == shLibName :
            print "      Removing Library"
            AdminConfig.remove(existingLibraryId)
            print "      Removed Library"
            break;


###############################################################################
# definition of the search routine
#
# parameters:
#
# shLibName   - the name of the node shared library
#
###############################################################################
def search( shLibName ):
    existingLibraryIds = AdminConfig.list('Library').split(lineSeparator)

    print "Found number of existing Libraries: %s" % (len(existingLibraryIds))

    for existingLibraryId in existingLibraryIds:
        if len(existingLibraryId) > 0:
            existingLibraryName = AdminConfig.showAttribute(existingLibraryId, 'name')
            print "      Library name: " + existingLibraryName
            if existingLibraryName == shLibName:
                return "true"
    return "false"


###############################################################################
# Main block -- script execution starts here
###############################################################################

# Uncomment the following line to enable tracing to the wsadmin.traceout file
# AdminControl.trace('com.ibm.*=all=enabled')

# Initialize the values necessary to create shared library
# The shared library value will have to be changed based on the install root
# that was specified by the Installer's user. i.e. replace C: with the
# value of the directory specified by user

# Verify the correct number or parameters was passed in
if not (len(sys.argv) == 4):
   sys.stderr.write("Invalid number of arguments\n")
   printUsage()
   sys.exit(101)

# retrieve the cell name
cellName = sys.argv[0]

# retrieve the node name
nodeName = sys.argv[1]

# retrieve the server name
serverName = sys.argv[2]

# retrieve the install directory
installDir = sys.argv[3]

birtShLibName  = "BIRT221_SH_LIB"
birtShLibDesc  = "A shared library that represents all BIRT jars"
birtShLibValue = installDir + "/lib/birt-runtime-2_2_1/ReportEngine/lib/chartengineapi.jar;" + installDir + "/lib/birt-runtime-2_2_1/ReportEngine/lib/commons-cli-1.0.jar;" + installDir + "/lib/birt-runtime-2_2_1/ReportEngine/lib/coreapi.jar;" + installDir + "/lib/birt-runtime-2_2_1/ReportEngine/lib/dataadapterapi.jar;" + installDir + "/lib/birt-runtime-2_2_1/ReportEngine/lib/dteapi.jar;" + installDir + "/lib/birt-runtime-2_2_1/ReportEngine/lib/engineapi.jar;" + installDir + "/lib/birt-runtime-2_2_1/ReportEngine/lib/flute.jar;" + installDir + "/lib/birt-runtime-2_2_1/ReportEngine/lib/js.jar;" + installDir + "/lib/birt-runtime-2_2_1/ReportEngine/lib/modelapi.jar;" + installDir + "/lib/birt-runtime-2_2_1/ReportEngine/lib/modelodaapi.jar;" + installDir + "/lib/birt-runtime-2_2_1/ReportEngine/lib/odadesignapi.jar;" + installDir + "/lib/birt-runtime-2_2_1/ReportEngine/lib/org.apache.commons.codec_1.3.0.v200706111738.jar;" + installDir + "/lib/birt-runtime-2_2_1/ReportEngine/lib/org.eclipse.emf.common_2.2.1.v200702131851.jar;" + installDir + "/lib/birt-runtime-2_2_1/ReportEngine/lib/org.eclipse.emf.ecore.xmi_2.2.2.v200702131851.jar;" + installDir + "/lib/birt-runtime-2_2_1/ReportEngine/lib/org.eclipse.emf.ecore_2.2.2.v200702131851.jar;" + installDir + "/lib/birt-runtime-2_2_1/ReportEngine/lib/org.w3c.css.sac_1.3.0.v200706111724.jar;" + installDir + "/lib/birt-runtime-2_2_1/ReportEngine/lib/scriptapi.jar"
successMsgBirt = "Shared library " + birtShLibName + " installed correctly on "

tcrShLibName  = "TCR111_SH_LIB"
tcrShLibDesc  = "A shared library that represents all shared Tivoli Common Reporting jars"
tcrShLibValue = installDir + "/lib/;" + installDir + "/lib/birt-runtime-2_2_1/ReportEngine/lib/com.ibm.icu_3.6.1.v20070906.jar"
successMsgTCR = "Shared library " + tcrShLibName + " installed correctly on "

tcrApp = "tcr"

add( nodeName, serverName, tcrShLibName, tcrShLibDesc, tcrShLibValue, tcrApp )
print "Finished executing add function"

print "Verifying the installation, if the library was installed correctly successMsg would be printed"

if search( tcrShLibName ) == "true":
   print successMsgTCR + tcrApp

else:
   sys.stderr.write("Shared library was not installed correctly\n")
   sys.exit(103)

add( nodeName, serverName, birtShLibName, birtShLibDesc, birtShLibValue, tcrApp )

print "Finished executing add function"

print "Verifying the installation, if the library was installed correctly successMsg would be printed"

if search(birtShLibName) == "true":
   print successMsgBirt + tcrApp
else:
   sys.stderr.write("Shared library was not installed correctly\n")
   sys.exit(103)