#!/bin/ksh


cancel() {

  $XSET
  retcd=$1


  if [[ -n "$DEBUG" ]]; then
    mkdir /tmp/debug_uninstall$$
	cp -r /tmp/*$$* /tmp/debug_uninstall$$ 2>/dev/null
  fi

  rm -f /tmp/*$$* 2>/dev/null

  exit $retcd

}

Initalize() {
  $XSET

  >/tmp/$$buffer
  >/tmp/$$buffer1
  unalias rm
  unset ALL ITM_HOME ALL PC REG_DIR ITM_BIN CONFIG_DIR

}


usage() {

  print "Usage:  uninstall_itm.sh -a -p pc  dir_name"
  print "\t-a - Removes all ITM objects (pc)"
  print "\t-p pc - product code to be removed"
  print "\tdir_name - ITM home directory"

  cancel 2
}


getoptions() {

  $XSET

  while getopts ":ap:" OPTION
  do
    if [[ $OPTION = ':' ]]; then
      print '\07Missing argument for option $OPTION'
      usage
    fi

    case $OPTION in
    a) 
      ALL=1
    ;;
    p)
      PC=$OPTARG
    ;;
  esac
  done
  
  shift $(($OPTIND - 1)) 
  ITM_HOME=$*

}

StopAllPC() {

 $XSET

 if [[ ! -f $CONFIG_DIR/RunInfo ]]; then
   return 0
 fi

 OIFS="$IFS"
 IFS="|"

 cat $CONFIG_DIR/RunInfo | while read tems_hostname pc_value pid tems level
 do
	if [[ "$pc_value" = "ms" ]]; then
       continue 
    fi

    if [[ -z "$tems_hostname" ]] || [[ -z "$pc_value" ]] || [[ -z "$pid" ]] \
      || [[ -z "$tems" ]] || [[ -z "$level" ]]; then
        continue
    fi
  
   IFS="$OIFS"

   $ITM_BIN/itmcmd agent -f stop $pc_value

   IFS="|"

 done

 IFS="$OIFS"

}
 
StopServer() {

 $XSET

 pc=ms

 if [[ ! -f $CONFIG_DIR/RunInfo ]]; then
   return 0
 fi

 OIFS="$IFS"
 IFS="|"
 found=0

 cat $CONFIG_DIR/RunInfo | while read tems_hostname pc_value pid tems level
 do
	if [[ "$pc_value" = "$pc" ]]; then
       found=1
       break 
    fi
 done

 IFS="$OIFS"
 if [[ $found -eq 1 ]]; then
   $ITM_BIN/CandleServer stop $tems
 fi

}

StopPC() {

 $XSET

 pc=$1

 if [[ ! -f $CONFIG_DIR/RunInfo ]]; then
   return 0
 fi

 OIFS="$IFS"
 IFS="|"
 found=0

 cat $CONFIG_DIR/RunInfo | while read tems_hostname pc_value pid tems level
 do
	if [[ "$pc_value" = "$pc" ]]; then
       found=1
       break 
    fi
 done

 IFS="$OIFS"
 if [[ $found -eq 1 ]]; then
   $ITM_BIN/itmcmd agent -f stop $pc
 fi

}
 

CheckAndSet() {

  $XSET

  if [[ -z "$ITM_HOME" ]]; then
    print "Must use the -d flag"
    usage
  fi

  REG_DIR=$ITM_HOME/registry
  CONFIG_DIR=$ITM_HOME/config/.ConfigData
  ITM_BIN=$ITM_HOME/bin

  if [[ -z "$ALL" ]] && [[ -z "$PC" ]]; then
    print "you must select -a or -p"
    usage
  fi
  if [[ -n "$ALL" ]] && [[ -n "$PC" ]]; then
    print "you can't select both -a and -p"
    usage
  fi

  if [[ ! -d $ITM_HOME ]]; then
   print "The directory $ITM_HOME does not exist"
   cancel 2
  fi
  if [[ ! -d $ITM_BIN ]]; then
   print "The directory $ITM_BIN does not exist"
   cancel 2
  fi
  if [[ ! -d $CONFIG_DIR ]]; then
   print "The directory $CONFIG_DIR does not exist"
   cancel 2
  fi
  if [[ ! -d $REG_DIR ]]; then
   print "The directory $REG_DIR does not exist"
   cancel 2
  fi


}

  

RemoveAll_PC() {

  $XSET

  cd $REG_DIR

  find *aix*.ver > /tmp/$$buffer 2>/dev/null

  rc=$?
  if [[ $rc -ne 0 ]]; then
	cancel $rc
  fi

  if [[ ! -s /tmp/$$buffer ]]; then
	cancel 0
  fi

  cat /tmp/$$buffer | while read file
  do
    pc_file=$(echo $file | cut -d "." -f1)
    grep -q $pc_file *aix*.ver
    if [[ $? -ne 0 ]]; then
      continue
    fi
    pc=$(echo $file | cut -c1-2)
    level=$(echo $file | cut -c3-8)
    print $pc $level >> /tmp/$$buffer1
  done

  cat /tmp/$$buffer1 | while read pc level
  do
    if [[ -n "$pc" ]] && [[ -n "$level" ]]; then
      RemoveITM_PC $pc $level
    fi
  done

  if [[ -d $ITM_HOME ]]; then
      cd /
      rm -fr $ITM_HOME 
  fi
  

}


RemoveOne_PC() {

  $XSET

  if [[ -z "$PC" ]]; then
    return 2 
  fi
  
  cd $REG_DIR

  find ${PC}aix*.ver > /tmp/$$buffer 2>/dev/null
  
  rc=$?
  if [[ $rc -ne 0 ]]; then
	cancel $rc
  fi

  if [[ ! -s /tmp/$$buffer ]]; then
	cancel 0
  fi

  cat /tmp/$$buffer | while read file
  do
    pc=$(echo $file | cut -c1-2)
    level=$(echo $file | cut -c3-8)
    print $pc $level >> /tmp/$$buffer1
  done

  cat /tmp/$$buffer1 | while read pc level
  do
    if [[ -n "$pc" ]] && [[ -n "$level" ]]; then
      RemoveITM_PC $pc $level
      if [[ -d $ITM_HOME/$level/$pc ]]; then
        cd $ITM_HOME/$level
        if [[ $? -eq 0 ]]; then
          rm -fr $PC
        fi
      fi
    fi
  done
  return 0
}


RemoveITM_PC() {

  $XSET

  itm_pc=$1
  itm_level=$2

  if [[ -z "$itm_pc" ]] && [[ -n "$itm_level" ]]; then
	return 1
  fi

  $ITM_BIN/uninstall.sh -i -f $itm_pc $itm_level

  rc=$?

  return $?
}


#
# Main
#

trap 'cancel 2'  1 2 3 15

if [ "$DEBUG" ]; then
  XSET='set -x'
  $XSET
fi

Initalize
getoptions "$@"
CheckAndSet

if [[ -n "$ALL" ]]; then
  StopAllPC
  StopServer
  RemoveAll_PC
  rc=$?
fi

if [[ -n "$PC" ]]; then
  StopPC $PC
  RemoveOne_PC 
  rc=$?
fi

cancel $?
